@@ -18,6 +18,8 @@ class DrupalApiPlugin(p.SingletonPlugin):
 
     def update_config(self, config_):
         tk.add_template_directory(config_, "templates")
+        tk.add_public_directory(config_, "assets")
+        tk.add_resource("assets", "ckanext-drupal-api")
         tk.add_ckan_admin_tab(config_, "drupal_api.drupal_api_config", "Drupal API")
 
     # IBlueprint
